> [!IMPORTANT]
> Version **3** is currently a BETA release.

![](https://raw.githubusercontent.com/TwitchIO/TwitchIO/main/logo.png)
[![](https://img.shields.io/badge/Python-3.11%20%7C%203.12%20%7C%203.13-blue.svg)](https://www.python.org)
![Pyright Strict](https://img.shields.io/badge/Pyright-Strict-b8dbb4)
![GitHub License](https://img.shields.io/github/license/PythonistaGuild/twitchio)

A powerful async Python library for the twitch API and EventSub. Fully featured, modern Object-Orientated design
with stateful objects.

TwitchIO provides ease of use when accessing the Twitch API with powerful extensions and hot-reloadable modules to help create
and manage applications on twitch.

**Features:**

- Modern ``async`` Python using ``asyncio``
- Fully annotated and complies with the ``pyright`` strict type-checker
- Intuitive with ease of use, using modern object orientated design
- Feature full including extensions for ``chat bots``, running ``routine tasks`` and ``playing sounds`` on stream (Conduits support soon...)
- Easily manage ``OAuth Tokens`` and data
- Built-in ``EventSub`` support via both ``Webhook`` and ``Websockets``

### Documentation
[Documentation](https://twitchio.dev/)
   
Getting Started
--------------------------------
[Installing](https://twitchio.dev/en/latest/getting-started/installing.html)

[Quickstart](https://twitchio.dev/en/latest/getting-started/quickstart.html)

[Examples](/examples)

### Support
For support using TwitchIO, please join the official [support server](https://discord.gg/RAKc3HF) on [Discord](https://discord.com/)

[![Discord Banner](https://discordapp.com/api/guilds/490948346773635102/widget.png?style=banner2)](https://discord.gg/RAKc3HF)

